/*
 * Copyright (C) 2014-2016 Brian L. Browning
 *
 * This file is part of Beagle
 *
 * Beagle is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Beagle is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package haplotype;

import vcf.Marker;
import vcf.Markers;
import vcf.PhasedGT;

/**
 * <p>Class {@code WrappedHapPairs} is a {@code HapPairs} instance
 * obtain by wrapping a {@code PhasedGT} object.
 * </p>
 * <p>Instances of {@code WrappedHapPairs} are immutable.
 * </p>
 *
 * @author Brian L. Browning {@code <browning@uw.edu>}
 */
public class WrappedHapPairs implements HapPairs {

    private final PhasedGT phasedGT;

    /**
     * Constructs a new {@code WrappedHapPairs} instance.
     * @param phasedGT the object to be wrapped by {@code this}
     * @throws NullPointerException if {@code phasedGT == null}
     */
    public WrappedHapPairs(PhasedGT phasedGT) {
        if (phasedGT==null) {
            throw new NullPointerException(PhasedGT.class.toString());
        }
        this.phasedGT = phasedGT;
    }

    @Override
    public int allele(int marker, int haplotype) {
        return phasedGT.allele(marker, haplotype);
    }

    @Override
    public int allele1(int marker, int hapPair) {
        return phasedGT.allele1(marker, hapPair);
    }

    @Override
    public int allele2(int marker, int hapPair) {
        return phasedGT.allele2(marker, hapPair);
    }

    @Override
    public int nMarkers() {
        return phasedGT.nMarkers();
    }

    @Override
    public Markers markers() {
        return phasedGT.markers();
    }

    @Override
    public Marker marker(int marker) {
        return phasedGT.marker(marker);
    }

    @Override
    public int nHaps() {
        return phasedGT.nHaps();
    }

    @Override
    public int nHapPairs() {
        return phasedGT.nSamples();
    }

    @Override
    public int idIndex(int hapPair) {
        return phasedGT.samples().idIndex(hapPair);
    }

}
