/*
 * Copyright (C) 2014-2016 Brian L. Browning
 *
 * This file is part of Beagle
 *
 * Beagle is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Beagle is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package vcf;

import beagleutil.Samples;

/**
 * <p>Class {@code PhasedGTWrapper} wraps a {@code GT} instance which
 * satisfies {@code gt.isPhased() == true}.
 * </p>
 * Instances of class {@code PhasedGTWrapper} are immutable.
 *
 * @author Brian L. Browning {@code <browning@uw.edu>}
 */
public class PhasedGTWrapper implements PhasedGT {

    private final GT gl;

    /**
     * Constructs a new {@code PhasedGTWrapper} instance from the specified
     * data.
     * @param gt the phased, non-missing genotypes to be wrapped
     *
     * @throws IllegalArgumentException if {@code gt.isPhased() == false}
     * @throws NullPointerException if {@code gt == null}
     */
    public PhasedGTWrapper(GT gt) {
        if (gt.isPhased() == false) {
            throw new IllegalArgumentException("gl.isRefData()==false");
        }
        this.gl = gt;
    }

    @Override
    public Samples samples() {
        return gl.samples();
    }

    @Override
    public int nSamples() {
        return gl.nSamples();
    }

    @Override
    public int allele1(int marker, int hapPair) {
            return gl.allele1(marker, hapPair);
    }

    @Override
    public int allele2(int marker, int hapPair) {
                    return gl.allele2(marker, hapPair);
    }

    @Override
    public int nMarkers() {
        return gl.nMarkers();
    }

    @Override
    public Markers markers() {
        return gl.markers();
    }

    @Override
    public Marker marker(int marker) {
        return gl.marker(marker);
    }

    @Override
    public int nHaps() {
        return 2*gl.nSamples();
    }
}
